<?php
  /**
 * Plugin class
 **/
if ( ! class_exists( 'ewbct_custom_image_field' ) ) {

class ewbct_custom_image_field {

  public function __construct() {
    //
  }
 
 /*
  * Initialize the class and start calling our hooks and filters
  * @since 1.0.0
 */
 public function init() {
   add_action( 'ewbrands_add_form_fields', array ( $this, 'add_category_image_ewbct' ), 10, 2 );
   add_action( 'created_ewbrands', array ( $this, 'save_category_image_ewbct' ), 10, 2 );
   add_action( 'ewbrands_edit_form_fields', array ( $this, 'update_category_image_ewbct' ), 10, 2 );
   add_action( 'edited_ewbrands', array ( $this, 'updated_category_image_ewbct' ), 10, 2 );
   add_action( 'admin_enqueue_scripts', array( $this, 'load_media_ewbct' ) );
   add_action( 'admin_footer', array ( $this, 'ewbct_add_script' ) );
 }

public function load_media_ewbct() {
 wp_enqueue_media();
}
 
 /*
  * Add a form field in the new category page
  * @since 1.0.0
 */
 public function add_category_image_ewbct ( $taxonomy ) { ?>
   <div class="form-field term-group">
     <label for="ewbct_category-image-id"><?php _e('Image', 'easy-woocommerce-brands'); ?></label>
     <input type="hidden" id="ewbct_category-image-id" name="ewbct_category-image-id" class="custom_media_url" value="">
     <div id="ewbct_category-image-wrapper"></div>
     <p>
       <input type="button" class="button button-secondary ewbct_ct_tax_media_button" id="ewbct_ct_tax_media_button" name="ewbct_ct_tax_media_button" value="<?php _e( 'Add Image', 'easy-woocommerce-brands' ); ?>" />
       <input type="button" class="button button-secondary ct_tax_media_remove" id="ct_tax_media_remove" name="ct_tax_media_remove" value="<?php _e( 'Remove Image', 'easy-woocommerce-brands' ); ?>" />
    </p>  
   </div>
 <?php
 }
 
 /*
  * Save the form field
  * @since 1.0.0
 */
 public function save_category_image_ewbct ( $term_id, $tt_id ) {
   $ewbct_image_input= sanitize_file_name($_POST['ewbct_category-image-id']);
   if( isset( $ewbct_image_input ) && '' !== $ewbct_image_input ){
     add_term_meta( $term_id, 'ewbct_category-image-id', $ewbct_image_input, true );
   }
 }
 
 /*
  * Edit the form field
  * @since 1.0.0
 */
 public function update_category_image_ewbct ( $term, $taxonomy ) { ?>
   <tr class="form-field term-group-wrap">
     <th scope="row">
       <label for="ewbct_category-image-id"><?php _e( 'Image', 'easy-woocommerce-brands' ); ?></label>
     </th>
     <td>
       <?php $image_id = get_term_meta ( $term -> term_id, 'ewbct_category-image-id', true ); ?>
       <input type="hidden" id="ewbct_category-image-id" name="ewbct_category-image-id" value="<?php echo $image_id; ?>">
       <div id="ewbct_category-image-wrapper">
         <?php if ( $image_id ) { ?>
           <?php echo wp_get_attachment_image ( $image_id, 'thumbnail' ); ?>
         <?php } ?>
       </div>
       <p>
         <input type="button" class="button button-secondary ewbct_ct_tax_media_button" id="ewbct_ct_tax_media_button" name="ewbct_ct_tax_media_button" value="<?php _e( 'Add Image', 'easy-woocommerce-brands' ); ?>" />
         <input type="button" class="button button-secondary ct_tax_media_remove" id="ct_tax_media_remove" name="ct_tax_media_remove" value="<?php _e( 'Remove Image', 'easy-woocommerce-brands' ); ?>" />
       </p>
     </td>
   </tr>
 <?php
 }

/*
 * Update the form field value
 * @since 1.0.0
 */
 public function updated_category_image_ewbct ( $term_id, $tt_id ) {
   $ewbct_image_input= sanitize_file_name($_POST['ewbct_category-image-id']);
   if( isset( $ewbct_image_input ) && '' !== $ewbct_image_input ){
     update_term_meta ( $term_id, 'ewbct_category-image-id', $ewbct_image_input );
   } else {
     update_term_meta ( $term_id, 'ewbct_category-image-id', '' );
   }
 }

/*
 * Add script
 * @since 1.0.0
 */
 public function ewbct_add_script() { ?>
   <script>
     jQuery(document).ready( function($) {
       function ct_media_upload(button_class) {
         var _custom_media = true,
         _orig_send_attachment = wp.media.editor.send.attachment;
         $('body').on('click', button_class, function(e) {
           var button_id = '#'+$(this).attr('id');
           var send_attachment_bkp = wp.media.editor.send.attachment;
           var button = $(button_id);
           _custom_media = true;
           wp.media.editor.send.attachment = function(props, attachment){
             if ( _custom_media ) {
               $('#ewbct_category-image-id').val(attachment.id);
               $('#ewbct_category-image-wrapper').html('<img class="custom_media_image" src="" style="margin:0;padding:0;max-height:100px;float:none;" />');
               $('#ewbct_category-image-wrapper .custom_media_image').attr('src',attachment.url).css('display','block');
             } else {
               return _orig_send_attachment.apply( button_id, [props, attachment] );
             }
            }
         wp.media.editor.open(button);
         return false;
       });
     }
     ct_media_upload('.ewbct_ct_tax_media_button.button'); 
     $('body').on('click','.ct_tax_media_remove',function(){
       $('#ewbct_category-image-id').val('');
       $('#ewbct_category-image-wrapper').html('<img class="custom_media_image" src="" style="margin:0;padding:0;max-height:100px;float:none;" />');
     });
     // Thanks: http://stackoverflow.com/questions/15281995/wordpress-create-category-ajax-response
     $(document).ajaxComplete(function(event, xhr, settings) {
       var queryStringArr = settings.data.split('&');
       if( $.inArray('action=add-tag', queryStringArr) !== -1 ){
         var xml = xhr.responseXML;
         $response = $(xml).find('term_id').text();
         if($response!=""){
           // Clear the thumb image
           $('#ewbct_category-image-wrapper').html('');
         }
       }
     });
   });
 </script>
 <?php }

  }
 
$ewbct_custom_image_field = new ewbct_custom_image_field();
$ewbct_custom_image_field -> init();
 
}
?>